@@ -11,6 +11,13 @@ import pytest
 import doctest
 from pytest_doctestplus.output_checker import OutputChecker, FLOAT_CMP
 
+try:
+    import pytest_asyncio  # noqa: F401
+    has_pytest_asyncio = True
+except ImportError:
+    has_pytest_asyncio = False
+
+
 
 pytest_plugins = ['pytester']
 
@@ -314,7 +321,7 @@ class TestFloats:
         c = OutputChecker()
         got = []
         for char in ['A', 'B', 'C', 'D', 'E']:
-            got.append('%s %s' % (char, float(ord(char))))
+            got.append(f'{char} {float(ord(char))}')
         got = '\n'.join(got)
 
         want = "A 65.0\nB 66.0\n...G 70.0"
@@ -428,6 +435,29 @@ def test_requires(testdir):
     testdir.inline_run(p, '--doctest-plus', '--doctest-rst').assertoutcome(skipped=1)
 
 
+def test_requires_all(testdir):
+    testdir.makeini(
+        """
+        [pytest]
+        doctestplus = enabled
+    """)
+
+    # should be ignored
+    p = testdir.makefile(
+        '.rst',
+        """
+        .. doctest-requires-all:: foobar
+
+            >>> import foobar
+
+        This is a narrative line, before another doctest snippet
+
+           >>> import foobar
+        """
+    )
+    testdir.inline_run(p, '--doctest-plus', '--doctest-rst').assertoutcome(skipped=1)
+
+
 def test_ignore_warnings_module(testdir):
 
     # First check that we get a warning if we don't add the IGNORE_WARNINGS
@@ -910,6 +940,41 @@ def test_doctest_skip(testdir):
     testdir.inline_run(p, '--doctest-plus', '--doctest-rst').assertoutcome(skipped=1)
 
 
+def test_remote_data_all(testdir):
+    testdir.makeini(
+        """
+        [pytest]
+        doctestplus = enabled
+    """)
+
+    p = testdir.makefile(
+        '.rst',
+        """
+        This is a narrative docs, which some of the lines requiring remote-data access.
+        The first code block always passes, the second is skipped without remote data and the
+        last section is skipped due to the all option.
+
+            >>> print("Test")
+            Test
+
+        .. doctest-remote-data-all::
+
+            >>> from contextlib import closing
+            >>> from urllib.request import urlopen
+            >>> with closing(urlopen('https://www.astropy.org')) as remote:
+            ...     remote.read()    # doctest: +IGNORE_OUTPUT
+
+        Narrative before a codeblock that should fail normally but with the all option in the
+        directive it is skipped over thus producing a passing status.
+
+            >>> print(123)
+        """
+    )
+
+    testdir.inline_run(p, '--doctest-plus', '--doctest-rst', '--remote-data').assertoutcome(failed=1)
+    testdir.inline_run(p, '--doctest-plus', '--doctest-rst').assertoutcome(passed=1)
+
+
 # We repeat all testst including remote data with and without it opted in
 def test_remote_data_url(testdir):
     testdir.makeini(
@@ -1123,6 +1188,9 @@ def test_fail_data_dependency(testdir, cont_on_fail):
     assert ("something()\nUNEXPECTED EXCEPTION: NameError" in report.longreprtext) is cont_on_fail
 
 
+@pytest.mark.xfail(
+        has_pytest_asyncio,
+        reason='pytest_asyncio monkey-patches .collect()')
 def test_main(testdir):
     pkg = testdir.mkdir('pkg')
     code = dedent(
@@ -1142,7 +1210,7 @@ def test_main(testdir):
 
 
 @pytest.mark.xfail(
-        python_version() in ('3.11.9', '3.11.10', '3.12.3'),
+        python_version() in ('3.11.9', '3.11.10', '3.11.11', '3.12.3'),
         reason='broken by https://github.com/python/cpython/pull/115440')
 def test_ufunc(testdir):
     pytest.importorskip('numpy')
